Title: [204389] trunk/Tools
Revision
204389
Author
aakash_j...@apple.com
Date
2016-08-11 14:25:08 -0700 (Thu, 11 Aug 2016)

Log Message

Keep EWS logs for longer
https://bugs.webkit.org/show_bug.cgi?id=160776

Reviewed by Daniel Bates.

* EWSTools/start-queue-mac.sh: Keep logs for 30 days instead of 14 days.

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (204388 => 204389)


--- trunk/Tools/ChangeLog	2016-08-11 21:21:55 UTC (rev 204388)
+++ trunk/Tools/ChangeLog	2016-08-11 21:25:08 UTC (rev 204389)
@@ -1,3 +1,12 @@
+2016-08-11  Aakash Jain  <aakash_j...@apple.com>
+
+        Keep EWS logs for longer
+        https://bugs.webkit.org/show_bug.cgi?id=160776
+
+        Reviewed by Daniel Bates.
+
+        * EWSTools/start-queue-mac.sh: Keep logs for 30 days instead of 14 days.
+
 2016-08-11  Simon Fraser  <simon.fra...@apple.com>
 
         iOS DRT/WTR project cleanup

Modified: trunk/Tools/EWSTools/start-queue-mac.sh (204388 => 204389)


--- trunk/Tools/EWSTools/start-queue-mac.sh	2016-08-11 21:21:55 UTC (rev 204388)
+++ trunk/Tools/EWSTools/start-queue-mac.sh	2016-08-11 21:25:08 UTC (rev 204389)
@@ -51,9 +51,9 @@
 TIME_TO_REBOOT=$(( $(date +%s) + 3600 * 12))
 
 while [ $TIME_TO_REBOOT -gt $(date +%s) ] || [ $(date +%H) -lt 1 ] || [ $(date +%H) -ge 6 ]; do
     # Delete log files older than 14 days, move aside the main $QUEUE_NAME-ews.log file to prevent it from growing extra large.
     cd $EWS_HOME/$QUEUE_NAME-logs
-    find . -mtime +14 -delete
+    find . -mtime +30 -delete
     if [ -s $QUEUE_NAME.log ]; then
         mv -f $QUEUE_NAME.log ${QUEUE_NAME}_$(date +%Y-%m-%d_%H-%m).log
     fi
@@ -51,9 +51,9 @@
 
 while [ $TIME_TO_REBOOT -gt $(date +%s) ] || [ $(date +%H) -lt 1 ] || [ $(date +%H) -ge 6 ]; do
-    # Delete log files older than 14 days, move aside the main $QUEUE_NAME-ews.log file to prevent it from growing extra large.
+    # Delete log files older than 30 days, move aside the main $QUEUE_NAME-ews.log file to prevent it from growing extra large.
     cd $EWS_HOME/$QUEUE_NAME-logs
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to